/*
 * Enemies
 */
 
 #ifndef ENEMIES_INCLUDED
        #define ENEMIES_INCLUDED

#include "gamecharacter.h"

class Enemy: public GameCharacter {
	protected:
		virtual void runController();
		Vect3d targetLocation;
		bool awake;
		virtual void hitWall(int blockx, int blocky);
		int thinkTime;
		int attackTime;
		int wallHitTime;
		Component meleeDamage;
		bool hasRangedAttack;
		
		void initThinkTime();
		void seekTarget();
		void fleeTarget();
		void think();
		virtual void doAttack() { };
	public:
		Enemy(Manager *m);
		virtual ~Enemy();
		void setTarget(const Vect3d &target);
		virtual void handleCollision(const Vect3d & overlap, GameObject *what);
		
};

class EnemyKnight : public Enemy {
	public:
		EnemyKnight(Manager *m) : Enemy(m) {
			firstSpriteNum = 0; // start of knight anim.
			animLength = 4; // knight /player anim length.
			spriteOffset = - KnightSpriteFloorLevel;
			deathSpriteNum = 32;
			deathAnimLength = 9;
			hasRangedAttack = false;
		}
	protected:
		virtual void doAttack();
		
};

class EnemyFairy : public Enemy {
	public:
		EnemyFairy(Manager *m) : Enemy(m) { 
			animLength = 2; // fairy anim length
			firstSpriteNum = 41; // start of fairy anim (S)
			maxSpeed = 4.0;
			spriteOffset = - FairySpriteFloorLevel;
			canTravelOnWater = true;
			deathSpriteNum = 57;
			deathAnimLength = 6;
			hitPoints = 40;
			hasRangedAttack = true;
		}
	protected:
		virtual void doAttack();
};

#endif  // PLAYERCHARACTER_INCLUDED
