/*
 * The game object 
 */
 
 #ifndef GAMEOBJECT_INCLUDED
        #define GAMEOBJECT_INCLUDED
// gameobject.h
// abstract base class
#include "vector3d.h"
#include "map.h"
#include "resourcemanager.h"

class Manager; // forward declaration to prevent recursion.
class PlayerCharacter; // ditto

class GameObject {
	protected:
		Manager *manager;
		Vect3d location;
		int layer;
		// Which block we're in.
		int blockx;
		int blocky;
		Component radius;
		bool visible;
		bool dead; // By dead, I mean REALLY dead as in gone forever
		// Not just not alive any more.
		bool collidable; // causes collision
		bool solid; // causes clip
		bool gettable;
	public:
		GameObject(Manager *m) : manager(m), layer(0), 
			visible(true), dead(false), collidable(true), 
			solid(true), gettable(false) { 
			radius = 0.3; // default.
		}
		bool isVisible() { return visible; }
		bool isDead() { return dead; }
		void setDead(bool b) { dead = b; }
		bool isCollidable() { return collidable; }
		bool isSolid() { return solid; }
		bool isGettable() { return gettable; }
		void setLocation(const Vect3d &where) {
			location = where;
			locationChanged();
		}
		virtual void locationChanged() { 
			blockx = (int) location.x;
			blocky = (int) location.y;
		}
		int getBlockX() { return blockx; }
		int getBlockY() { return blocky; }
		int getLayer() { return layer; }
		void setLayer(int l ) { layer = l; }
		Vect3d getLocation() { return location; }
		Component getRadius() { return radius; }
		virtual void handleCollision(const Vect3d &amount, GameObject *what);
		virtual ~GameObject() { }
		virtual void render() = 0;
		virtual void runLogic() = 0;
		virtual void damage(Component amount) { }
		virtual void gotBy(PlayerCharacter *p) { }
};

class SpriteObject : public GameObject {
	public:
		SpriteObject(Manager *m) : GameObject(m) { solid = true; }
		virtual ~SpriteObject() { }
		virtual void render();
		virtual void runLogic();
		virtual void locationChanged();
	protected:
		ResourceManager::SpriteSet spriteSet;
		int spriteNum;
		float spriteScale;
		float spriteOffset;
};

// An item which sits there, doing nothing.
// When set to a particular location, attempts to plant itself on the ground.

class StaticObject : public SpriteObject {
	public:
		enum StaticObjectType { XChest, YChest, Vase, Skull, SkullPile, Goat };
	private:
		StaticObjectType type;
	public:
		StaticObject(Manager *m) : SpriteObject(m), type(XChest) { solid = true; }
		StaticObject(Manager *m, StaticObjectType type);
		virtual ~StaticObject() { }
		// Static objects never move, even if things hit them.
		virtual void handleCollision(const Vect3d &amount, GameObject *what) { }
		virtual void gotBy(PlayerCharacter *p);
};

#endif  // GAMEOBJECT_INCLUDED
