/*
 * hud.h
 */
 
#include "hud.h"
#include "constants.h"
#include "gameoptions.h"
#include <cstdio>
 
static void RenderHudFace(float bottomy, float topy, int num)
{
	float texMinX = ((float) num * (1.0 / 8.0));
	float texMaxX = texMinX + (1.0 / 8.0);
	float leftx = -2;
	float rightx = leftx + (topy - bottomy);
	glBegin(GL_TRIANGLE_STRIP);
	glTexCoord2d(texMinX,0);
	glVertex2f(leftx, topy);
	glTexCoord2d(texMinX, 1);
	glVertex2f(leftx, bottomy);
	glTexCoord2d(texMaxX,0);
	glVertex2f(rightx, topy);
	glTexCoord2d(texMaxX, 1);
	glVertex2f(rightx, bottomy);
	glEnd();
}

void RenderPain(Component painLevel, float bottomy, float leftx)
{
	if (painLevel < 1) {
		return;
	}
	if (painLevel > 20) {
		painLevel = 20;
	}
	// Render a big blended quad over everythign which tints the screen red.
	glEnable(GL_BLEND);
	glDisable(GL_TEXTURE_2D);
        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
	glBegin(GL_QUADS);
	
	glColor4f(1,0,0, (painLevel * 0.02));
	glVertex2f(-leftx, bottomy);
	glVertex2f(-leftx, -bottomy);
	glVertex2f(leftx, -bottomy);
	glVertex2f(leftx, bottomy);
	glEnd();

}

// This should be called near the end of rendering.
// It will trash the trans. matrix.
void RenderHud(Manager &man)
{
	if (gameOptions.disableHud) {
		return;
	}

	glEnable(GL_TEXTURE_2D);
	glDisable(GL_BLEND); // No blending in HUD.
	
	glColor3f(1,1,1); // full brighteness hud.
	man.rm.selectHudTexture();
	glMatrixMode(GL_MODELVIEW);
  	glLoadIdentity();
	float texMaxX = 1.0;
	float texMaxY = (24.0 / 32.0);
	float aspect = (float) ScreenWide / (float) ScreenHigh;
	float rightx = (UltimateUnitsWide / 2);
	float leftx = - rightx;
	float bottomy = leftx / aspect;
	float topy = bottomy + (((float)UltimateUnitsWide * 30.0) / 320.0);
	glBegin(GL_TRIANGLE_STRIP);
	glTexCoord2d(0,0);
	glVertex2f(leftx, topy);
	glTexCoord2d(0, texMaxY);
	glVertex2f(leftx, bottomy);
	glTexCoord2d(texMaxX,0);
	glVertex2f(rightx, topy);
	glTexCoord2d(texMaxX, texMaxY);
	glVertex2f(rightx, bottomy);
	glEnd();
	man.rm.selectFaceTexture();
	PlayerCharacter * player = man.getPlayer();
	int health = (int) player->getHitPoints();
	int ammo = player->getAmmo();
	if (health < 0) health = 0;
	// face num based on health.
	int faceNum = 4 - ((health + 24) / 25);
	RenderHudFace(bottomy, topy, faceNum);
	
	// Do the health thing.
	float healthx = -4;
	float healthy = topy - 0.1;
	int colour = makecol(255,0,0);
	glEnable(GL_BLEND); // Blend the text.
	glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_COLOR);
	allegro_gl_printf(man.rm.getMainFont(),  // font
		healthx, healthy, 0, // x,y,z
		colour, // colour
		"%02d", health);
	// Ammo - show if gun selected.
	if (player->getWeapon() != PlayerCharacter::Fist) {
		float ammox = -5.5;
		float ammoy = healthy;
		allegro_gl_printf(man.rm.getMainFont(),  // font
			ammox, ammoy, 0, // x,y,z
			colour, // colour
			"%02d%", ammo);
	}
		
	RenderPain(player->getPainLevel(), bottomy, leftx);
}

