#ifndef MANAGER_INCLUDED
        #define MANAGER_INCLUDED

#include "map.h"
#include "resourcemanager.h"
#include "vector3d.h"
#include "gameobject.h"

#include <vector>

/*
 * manager.h
 *
 * The manager is responsible for doing:
 * - Object management
 * - Rendering stuff in the right order
 * - Clipping rendering area etc.
 */
 
// Forward
class PlayerCharacter;
 
class Manager {
	public:
		Manager();
		~Manager();
		void render();
		void runLogic();
		void drawTextAt(const char * msg, float x, float y, float z);
		void initObjects(); //  CALL THIS ONCE per game
		void initLevel(); // This once per level.
		void addObject(GameObject *obj);
		Vect3d getCentre() {
			return mapCentre;
		}
		int getCurrentLayer() {
			return currentLayer;
		}
		// A left-click.
		void handleClick(Component x, Component y);
		// A RMB click, or ctrl.
		void handleAttack(Component x, Component y);
		void selectWeapon(int w);
		void relocatePlayer(Vect3d where, int layer);
		void areaDamage(const Vect3d &where, Component amount, Component radius, GameObject *avoid);
		PlayerCharacter * getPlayer() {
			return player;
		}
		int levelNum;
	public:
		Map map;
		ResourceManager rm;
		bool levelComplete;
	private:
		int currentLayer;
		Vect3d mapCentre;
		void renderMap();
		void renderBlock(int x, int y);
		typedef std::vector <GameObject *> GameObjectList;
		typedef GameObjectList::iterator GameObjectIterator;
		GameObjectList liveObjects;
		GameObjectList deadObjects;
		GameObjectList newObjects;
		void clearObjects(GameObjectList &list);
		void clearDeads();
		void collideTest(GameObject *first, GameObject *second);
		void checkCollisions();
		GameObject * trackObject;
		PlayerCharacter * player;
};

#endif // MANAGER_INCLUDED

