/*
 * Resource manager object
 */
#ifndef _RM_INCLUDED
#define _RM_INCLUDED



#include <alleggl.h>
#include <vector>
  
// Existing mainly to destroy things neatly.
// NOTE: We will not load anything in the constructor.
// Instead, we will have a load method. This means that if we throw
// An exception, the destructor will be called. This will clean up any
// Items which we've already loaded.

class ResourceManager {
	private:
		DATAFILE * fontsfile;
		FONT *mainfont;
		std::vector <GLuint> textures;
		std::vector < std::vector<GLuint> > spriteSets;
		GLuint hudtex;
		GLuint facestex;
	public:
		enum SpriteSet { SpriteSetMisc, SpriteSetMainChar, SpriteSetEnemies };
		static const int SpriteSetMax = SpriteSetEnemies;
		// Reset everything to an unloaded state.
		ResourceManager() : fontsfile(0), mainfont(0) {
			// clear it all out.
			hudtex = 0;
			facestex = 0;
		}
		
		FONT * getMainFont() { return mainfont; }
		FONT * getAllegroFont() { return (FONT*)fontsfile[0].dat; }
		
		~ResourceManager();
		void load();
		void selectTexture(int n);
		void selectSprite(SpriteSet set, int n);
		void selectHudTexture() {
			glBindTexture(GL_TEXTURE_2D, hudtex);
		}
		void selectFaceTexture() {
			glBindTexture(GL_TEXTURE_2D, facestex);
		}
	private:
		void loadTextures();
		void loadSprites();
		void loadSpriteSet(const char *filename, SpriteSet set, int spritesize);
		void loadHud();
		void generateSprites();

};

#endif // _RM_INCLUDED

