/*
 * shot.cpp
 */
#include "shot.h"
#include "manager.h"
#include "graphics_offsets.h"

const Component ShotRadius = 0.3;

void Shot::render()
{
	// Render a blob sprite
	glEnable(GL_TEXTURE_2D);
	glEnable(GL_BLEND); // Enable Blending
	// Whacky blending.
        glBlendFunc(GL_ONE,GL_ONE_MINUS_SRC_COLOR);
	
	float scale = 0.25;
	float zoffset = 0.7;
	glColor3f(1,1,1);
	int spritenum = skull ? ObjectSkull : ObjectBlob;
	manager->rm.selectSprite(ResourceManager::SpriteSetMisc, spritenum);
	glBegin(GL_TRIANGLE_STRIP);
	float leftx = (location.x - scale);
	float lefty = (location.y + scale);
	float rightx = (location.x + scale);
	float righty = (location.y - scale);
	float bottomz = location.z + zoffset;
	float topz = bottomz + (scale * 2 * RootTwo);
	float texmin = 0;
	float texmax = 1;
	if (skull) {
		texmin = 0.3;
		texmax = 0.7;
	}
	glTexCoord2f(texmin, texmin);
	glVertex3f(leftx, lefty, topz);
	glTexCoord2f(texmin,texmax);
	glVertex3f(leftx, lefty, bottomz);
	glTexCoord2f(texmax,texmin);
	glVertex3f(rightx, righty, topz);
	glTexCoord2f(texmax, texmax);
	glVertex3f(rightx, righty, bottomz);
	glEnd();
	glDisable(GL_BLEND); // Restore
}

void Shot::blowUp()
{
	blownUp = true;
	velocity = Vect3d(0,0,0);
	// Cause area damage.
	manager->areaDamage(location, damage, ShotRadius, this);
	// can't collide anymore once blown up.
	collidable = false;
}

void Shot::runLogic()
{
	if (blownUp) {
		blownUpTimer ++;
		if (blownUpTimer > 100) {
			dead = true;
		}
	} else {
		location = location + (velocity * 0.01);
		locationChanged();
		// Check for wall collision.
		// Check for future wall collision:
		Vect3d fwd(location + (velocity * 0.05));
		if (manager->map.isBlocked((int) fwd.x, (int) fwd.y, layer)) {
			blowUp();
		}
	}
}

void Shot::handleCollision(const Vect3d & overlap, GameObject *what)
{
	// Shots can't collide with their owners.
	// They can damage their owners with area effect.
	if (what != owner) {
		// Blow up shell.
		blowUp();
	}
}
